@@ -141,6 +141,21 @@ const SimpleDefaults SimpleParser6::GLOBAL6_DEFAULTS = {
     { "allocator",                        Element::string,  "iterative" },
     { "pd-allocator",                     Element::string,  "iterative" },
     { "ddns-conflict-resolution-mode",    Element::string,  "check-with-dhcid" },
+    { "cache-threshold",                  Element::real,    "0.25" },
+};
+
+const SimpleKeywords SimpleParser6::GLOBAL6_LIST_PARAMETERS = {
+    { "host-reservation-identifiers", Element::list },
+    /* not yet supported
+    { "interfaces-config.interfaces", Element::list },
+    */
+};
+
+const SimpleKeywords SimpleParser6::GLOBAL6_LIST_PARAMETER_TYPES = {
+    { "host-reservation-identifiers", Element::string },
+    /* not yet supported
+    { "interfaces-config.interfaces", Element::string },
+    */
 };
 
 /// @brief This table defines all option definition parameters.
