@@ -371,7 +371,8 @@ TestConfigBackendDHCPv4::getModifiedOptionDefs4(const db::ServerSelector& server
 OptionDescriptorPtr
 TestConfigBackendDHCPv4::getOption4(const db::ServerSelector& server_selector,
                                     const uint16_t code,
-                                    const std::string& space) const {
+                                    const std::string& space,
+                                    const ClientClassesPtr client_classes) const {
     auto tags = server_selector.getTags();
     auto candidate = OptionDescriptorPtr();
     auto const& index = options_.get<1>();
@@ -379,11 +380,16 @@ TestConfigBackendDHCPv4::getOption4(const db::ServerSelector& server_selector,
 
     BOOST_FOREACH(auto const& option_it, option_it_pair) {
         if (option_it.space_name_ == space) {
+            if (client_classes && (option_it.client_classes_ != *client_classes)) {
+                continue;
+            }
+
             for (auto const& tag : tags) {
                 if (option_it.hasServerTag(ServerTag(tag))) {
                     return (OptionDescriptorPtr(new OptionDescriptor(option_it)));
                 }
             }
+
             if (option_it.hasAllServerTag()) {
                 candidate = OptionDescriptorPtr(new OptionDescriptor(option_it));
             }
@@ -463,7 +469,6 @@ TestConfigBackendDHCPv4::getGlobalParameter4(const db::ServerSelector& server_se
     return (candidate);
 }
 
-
 StampedValueCollection
 TestConfigBackendDHCPv4::getAllGlobalParameters4(const db::ServerSelector& server_selector) const {
     auto tags = server_selector.getTags();
@@ -742,6 +747,7 @@ TestConfigBackendDHCPv4::createUpdateOption4(const db::ServerSelector& server_se
          option_it != option_it_pair.second;
          ++option_it) {
         if ((option_it->space_name_ == option->space_name_) &&
+            (option_it->client_classes_ == option->client_classes_) &&
             (option_it->hasServerTag(ServerTag(tag)))) {
             index.replace(option_it, *option);
             return;
@@ -788,7 +794,8 @@ TestConfigBackendDHCPv4::createUpdateOption4(const db::ServerSelector& server_se
                   << " not present in a selected server");
     }
 
-    shared_network->getCfgOption()->del(option->space_name_, option->option_->getType());
+    shared_network->getCfgOption()->del(option->space_name_, option->option_->getType(),
+                                        option->client_classes_);
     shared_network->getCfgOption()->add(*option, option->space_name_);
 }
 
@@ -829,7 +836,8 @@ TestConfigBackendDHCPv4::createUpdateOption4(const db::ServerSelector& server_se
                   << " not present in a selected server");
     }
 
-    subnet->getCfgOption()->del(option->space_name_, option->option_->getType());
+    subnet->getCfgOption()->del(option->space_name_, option->option_->getType(),
+                                option->client_classes_);
     subnet->getCfgOption()->add(*option, option->space_name_);
 }
 
@@ -869,7 +877,8 @@ TestConfigBackendDHCPv4::createUpdateOption4(const db::ServerSelector& server_se
         }
 
         // Update the option.
-        pool->getCfgOption()->del(option->space_name_, option->option_->getType());
+        pool->getCfgOption()->del(option->space_name_, option->option_->getType(),
+                                  option->client_classes_);
         pool->getCfgOption()->add(*option, option->space_name_);
 
         return;
@@ -1175,13 +1184,15 @@ TestConfigBackendDHCPv4::deleteAllOptionDefs4(const db::ServerSelector& server_s
 uint64_t
 TestConfigBackendDHCPv4::deleteOption4(const db::ServerSelector& server_selector,
                                        const uint16_t code,
-                                       const std::string& space) {
+                                       const std::string& space,
+                                       ClientClassesPtr client_classes) {
     auto tag = getServerTag(server_selector);
     uint64_t erased = 0;
     for (auto option_it = options_.begin(); option_it != options_.end(); ) {
         if ((option_it->option_->getType() == code) &&
             (option_it->space_name_ == space) &&
-            (option_it->hasServerTag(ServerTag(tag)))) {
+            (option_it->hasServerTag(ServerTag(tag))) &&
+            (!client_classes || (option_it->client_classes_ == *client_classes))) {
             option_it = options_.erase(option_it);
             ++erased;
         } else {
@@ -1195,7 +1206,8 @@ uint64_t
 TestConfigBackendDHCPv4::deleteOption4(const db::ServerSelector& server_selector,
                                        const std::string& shared_network_name,
                                        const uint16_t code,
-                                       const std::string& space) {
+                                       const std::string& space,
+                                       ClientClassesPtr client_classes) {
     auto& index = shared_networks_.get<SharedNetworkNameIndexTag>();
     auto network_it = index.find(shared_network_name);
 
@@ -1223,12 +1235,17 @@ TestConfigBackendDHCPv4::deleteOption4(const db::ServerSelector& server_selector
             }
         }
     }
+
     if (!found) {
         isc_throw(BadValue, "attempted to delete option in a "
                   "shared network " << shared_network_name
                   << " not present in a selected server");
     }
 
+    if (client_classes) {
+        return (shared_network->getCfgOption()->del(space, code, *client_classes));
+    }
+
     return (shared_network->getCfgOption()->del(space, code));
 }
 
@@ -1236,7 +1253,8 @@ uint64_t
 TestConfigBackendDHCPv4::deleteOption4(const db::ServerSelector& server_selector,
                                        const SubnetID& subnet_id,
                                        const uint16_t code,
-                                       const std::string& space) {
+                                       const std::string& space,
+                                       ClientClassesPtr client_classes) {
     auto& index = subnets_.get<SubnetSubnetIdIndexTag>();
     auto subnet_it = index.find(subnet_id);
 
@@ -1270,6 +1288,10 @@ TestConfigBackendDHCPv4::deleteOption4(const db::ServerSelector& server_selector
                   << " not present in a selected server");
     }
 
+    if (client_classes) {
+        return (subnet->getCfgOption()->del(space, code, *client_classes));
+    }
+
     return (subnet->getCfgOption()->del(space, code));
 }
 
@@ -1278,7 +1300,8 @@ TestConfigBackendDHCPv4::deleteOption4(const db::ServerSelector& server_selector
                                        const asiolink::IOAddress& pool_start_address,
                                        const asiolink::IOAddress& pool_end_address,
                                        const uint16_t code,
-                                       const std::string& space) {
+                                       const std::string& space,
+                                       ClientClassesPtr client_classes) {
     auto not_in_selected_servers = false;
     for (auto const& subnet : subnets_) {
         // Get the pool: if it is not here we can directly go to the next subnet.
@@ -1310,6 +1333,10 @@ TestConfigBackendDHCPv4::deleteOption4(const db::ServerSelector& server_selector
             }
         }
 
+        if (client_classes) {
+            return (pool->getCfgOption()->del(space, code, *client_classes));
+        }
+
         return (pool->getCfgOption()->del(space, code));
     }
 
